/*
 *  Database record class for DAAP sharing
 *
 *  Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __DMAPD_DAAP_RECORD
#define __DMAPD_DAAP_RECORD

#include <libdmapsharing/daap-record.h>

G_BEGIN_DECLS

#define TYPE_DMAPD_DAAP_RECORD         (dmapd_daap_record_get_type ())
#define DMAPD_DAAP_RECORD(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_DMAPD_DAAP_RECORD, DmapdDAAPRecord))
#define DMAPD_DAAP_RECORD_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), TYPE_DMAPD_DAAP_RECORD, DmapdDAAPRecordClass))
#define IS_DMAPD_DAAP_RECORD(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_DMAPD_DAAP_RECORD))
#define IS_DMAPD_DAAP_RECORD_CLASS (k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_DMAPD_DAAP_RECORD_CLASS))
#define DMAPD_DAAP_RECORD_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_DMAPD_DAAP_RECORD, DmapdDAAPRecordClass))
#define DMAPD_DAAP_RECORD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_DMAPD_DAAP_RECORD, DmapdDAAPRecordPrivate))

typedef struct DmapdDAAPRecordPrivate DmapdDAAPRecordPrivate;

typedef struct {
	GObject parent;
	DmapdDAAPRecordPrivate *priv;
} DmapdDAAPRecord;

typedef struct {
	GObjectClass parent;
} DmapdDAAPRecordClass;

GType dmapd_daap_record_get_type (void);

DmapdDAAPRecord *dmapd_daap_record_new (const char *location);

gint          dmapd_daap_record_get_id          (DAAPRecord *record);

const char   *dmapd_daap_record_get_location    (DAAPRecord *record);

const char   *dmapd_daap_record_get_title       (DAAPRecord *record);

gint          dmapd_daap_record_get_filesize	(DAAPRecord *record);

gint          dmapd_daap_record_get_rating	(DAAPRecord *record);

const char   *dmapd_daap_record_get_album	(DAAPRecord *record);

const char   *dmapd_daap_record_get_artist	(DAAPRecord *record);

const char   *dmapd_daap_record_get_genre 	(DAAPRecord *record);

const char   *dmapd_daap_record_get_format	(DAAPRecord *record);

gint32        dmapd_daap_record_get_duration	(DAAPRecord *record);

gint32        dmapd_daap_record_get_track   	(DAAPRecord *record);

gint32        dmapd_daap_record_get_year    	(DAAPRecord *record);

gint32        dmapd_daap_record_get_firstseen	(DAAPRecord *record);

gint32        dmapd_daap_record_get_mtime    	(DAAPRecord *record);

gint32        dmapd_daap_record_get_disc     	(DAAPRecord *record);

gint32        dmapd_daap_record_get_bitrate  	(DAAPRecord *record);

gint8         dmapd_daap_record_has_video       (DAAPRecord *record);

GInputStream *dmapd_daap_record_read            (DAAPRecord *record,
						 GError **err);

#endif /* __DMAPD_DAAP_RECORD */

G_END_DECLS
