/*   FILE: util.c -- utility functions
 * AUTHOR: W. Michael Petullo <mike@flyn.org>
 *   DATE: 01 January 2009 
 *
 * Copyright (c) 2009 W. Michael Petullo <new@flyn.org>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <libdmapsharing/dmap-md5.h>

#include "util.h"

gchar *
cache_path (gchar *imagepath)
{
	gchar *cachepath = NULL;
	guchar hash[33] = {0};

	dmap_hash_generate (1, (const guchar*) imagepath, 2, hash, 0);
	cachepath = g_strdup_printf ("/var/cache/dmapd/%s", hash);

	return cachepath;
}

GByteArray *
cache_read (gchar *imagepath)
{
	gchar *data;
	size_t size;
	GByteArray *blob = NULL;
	gchar *cachepath;
	GError *error = NULL;

	cachepath = cache_path (imagepath);

	g_file_get_contents (cachepath, &data, &size, &error);
	if (error != NULL) {
		g_warning ("No record cached at %s", cachepath);
	} else {
		blob = g_byte_array_new ();
		g_byte_array_append (blob, data, size);
		g_free (data);
	}

	g_free (cachepath);

	return blob;
}

void
cache_store (gchar *imagepath, GByteArray *blob, size_t size)
{
	gchar *cachepath;
	GError *error = NULL;
	cachepath = cache_path (imagepath);
	g_file_set_contents (cachepath, blob->data, size, &error);
	if (error != NULL) {
		g_error ("Error writing %s", cachepath);
	}

	g_free (cachepath);
}

gboolean
pads_compatible (GstPad *pad1, GstPad *pad2)
{
	gboolean fnval;
	GstCaps *res, *caps1, *caps2;

	caps1 = gst_pad_get_caps (pad1);
	caps2 = gst_pad_get_caps (pad2);
	res = gst_caps_intersect (caps1, caps2);
	fnval = res && ! gst_caps_is_empty (res);

	gst_caps_unref (res);
	gst_caps_unref (caps2);
	gst_caps_unref (caps1);

	return fnval;
}
